| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Pqi.Ffi
Description
The FFI adapter, backed by postgresql-libpq.
adapter bundles the three functions that produce a Connection
whose fields are closures over the underlying C-backed PGconn.
Result and Cancel values are constructed the same way, closing
over the underlying PGresult/PGcancel.
Each closure is a near-mechanical delegation to the matching
Database.PostgreSQL.LibPQ function, with the only work being the
conversion between this family's portable types (OIDs as Word32, indices
as Int32, the shared enums) and postgresql-libpq's C-specific newtypes.